@@ -1,4 +1,4 @@
-# ABSTRACT: Perl 5 API wrapper for Stripe
+# ABSTRACT: Stripe.com API Client
 package API::Stripe;
 
 use namespace::autoclean -except => 'has';
@@ -12,7 +12,7 @@ use Data::Object::Library qw(Str);
 
 extends 'API::Client';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our $DEFAULT_URL = "https://api.stripe.com";
 
@@ -91,11 +91,11 @@ __END__
 
 =head1 NAME
 
-API::Stripe - Perl 5 API wrapper for Stripe
+API::Stripe - Stripe.com API Client
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -153,7 +153,7 @@ The debug attribute if true prints HTTP requests and responses to standard out.
     $stripe->fatal(1);
 
 The fatal attribute if true promotes 4xx and 5xx server response codes to
-exceptions, a L<API::Stripe::Exception> object.
+exceptions, a L<API::Client::Exception> object.
 
 =head2 retries
 
